mtd/drivers/mtd/maps ixp2000.c,1.1,1.2
David Woodhouse
dwmw2 at infradead.org
Tue Sep 14 16:56:24 EDT 2004
Update of /home/cvs/mtd/drivers/mtd/maps
In directory phoenix.infradead.org:/tmp/cvs-serv12693
Modified Files:
ixp2000.c
Log Message:
Pedantry
Index: ixp2000.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/maps/ixp2000.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ixp2000.c 2 Sep 2004 00:13:41 -0000 1.1
+++ ixp2000.c 14 Sep 2004 20:56:21 -0000 1.2
@@ -55,13 +55,13 @@
/*
* Rev A0 and A1 of IXP2400 silicon have a broken addressing unit which
* causes the lower address bits to be XORed with 0x11 on 8 bit accesses
* and XORed with 0x10 on 16 bit accesses. See the spec update, erratta 44.
*/
-static int errata44_workaround = 0;
+static int erratum44_workaround = 0;
static inline unsigned long address_fix8_write(unsigned long addr)
{
- if (errata44_workaround) {
+ if (erratum44_workaround) {
return (addr ^ 3);
}
return addr;
@@ -160,7 +160,7 @@
return -ENODEV;
window_size = dev->resource->end - dev->resource->start + 1;
- dev_info(_dev, "Probe of IXP2000 flash(%d banks x %dM)\n",
+ dev_info(_dev, "Probe of IXP2000 flash(%d banks x %dMiB)\n",
ixp_data->nr_banks, ((u32)window_size >> 20));
if (plat->width != 1) {
@@ -224,12 +224,12 @@
#if defined(__ARMEB__)
/*
* Enable errata 44 workaround for NPUs with broken slowport
*/
errata44_workaround = ixp2000_has_broken_slowport();
- dev_info(_dev, "Errata 44 workaround %s\n",
- errata44_workaround ? "enabled" : "disabled");
+ dev_info(_dev, "Erratum 44 workaround %s\n",
+ erratum44_workaround ? "enabled" : "disabled");
#endif
info->mtd = do_map_probe(plat->map_name, &info->map);
More information about the linux-mtd-cvs
@@ -55,13 +55,13 @@
* Rev A0 and A1 of IXP2400 silicon have a broken addressing unit which
* causes the lower address bits to be XORed with 0x11 on 8 bit accesses
- * and XORed with 0x10 on 16 bit accesses. See the spec update, erratta 44.
+ * and XORed with 0x10 on 16 bit accesses. See the spec update, erratum 44.
*/
@@ -224,12 +224,12 @@
#if defined(__ARMEB__)
/*
- * Enable errata 44 workaround for NPUs with broken slowport
+ * Enable erratum 44 workaround for NPUs with broken slowport
*/
errata44_workaround = ixp2000_has_broken_slowport();
mailing list